@@ -10,6 +10,7 @@ LOG = logging.getLogger(__name__)
 
 SGBD_MYSQL = 'M'
 SGBD_MONGODB = 'G'
+SGBD_REDIS = 'R'
 
 
 class DBMonitorProvider(object):
@@ -46,6 +47,8 @@ class DBMonitorProvider(object):
             return SGBD_MONGODB
         elif re.match(r'^mysql.*', driver_name):
             return SGBD_MYSQL
+        elif re.match(r'^redis.*', driver_name):
+            return SGBD_REDIS
         else:
             LOG.error('Not implemented engine type')
             raise NotImplementedError()
@@ -67,7 +70,7 @@ class DBMonitorProvider(object):
             flag_cluster = True
             machine = ''
         
-        if sgbd == SGBD_MYSQL:
+        if sgbd == SGBD_MYSQL or sgbd == SGBD_REDIS:
             dns, port = databaseinfra.endpoint_dns.split(':')
             replicasetname = ''
         else:
